@@ -5,7 +5,7 @@
 ############################################################################################
 
 derived <- function (object, sessnum = NULL, groups=NULL, alpha=0.05, se.esa = FALSE, 
-    se.D = TRUE, loginterval = FALSE, distribution = NULL) {
+    se.D = TRUE, loginterval = TRUE, distribution = NULL) {
 
 ## Generate table of derived parameters from fitted secr object
 
@@ -48,10 +48,10 @@ derived <- function (object, sessnum = NULL, groups=NULL, alpha=0.05, se.esa = F
            else nrow(mask[[asess]]) * attr(mask[[asess]],'area')
         }
         se.deriveD <- function (selection, selected.a, asess) { 
-            CLg  <- CLgradient (object, selection, asess)
             s2 <- switch (tolower(object$details$distribution),
                poisson  = sum (1/selected.a^2),  
                binomial = sum (( 1 - selected.a / maskarea(object$mask, asess)) / selected.a^2))
+            CLg  <- CLgradient (object, selection, asess)
             varDn <- CLg %*% object$beta.vcv %*% CLg
             list(SE=sqrt(s2 + varDn), s2=s2, varDn=varDn)
         }
@@ -98,6 +98,7 @@ derived <- function (object, sessnum = NULL, groups=NULL, alpha=0.05, se.esa = F
         else capthist <- object$capthist[[sessnum]] 
         grp <- group.factor(capthist, groups)  ## see functions.R
         individuals <- split (1:nrow(capthist), grp)
+
         if ( length(individuals) > 1) lapply (individuals, getderived)
         else getderived(individuals[[1]])
     }
