@@ -3,11 +3,12 @@
 ## Method for plotting detection function from fitted secr object
 ## 2009 02 12 2009 08 09 2009 09 13 (limits)
 ## 2009 11 04 signal strength
+## 2010 07 01 alpha detectfn
 ############################################################################################
 
-plot.secr <- function (x, newdata=NULL, add = FALSE, 
-    sigmatick = FALSE, rgr = FALSE, limits = TRUE, alpha = 0.05, xval = 0:200, 
-    ylim = NULL, xlab = NULL, ylab = NULL, ...) 
+plot.secr <- function (x, newdata=NULL, add = FALSE,
+    sigmatick = FALSE, rgr = FALSE, limits = TRUE, alpha = 0.05, xval = 0:200,
+    ylim = NULL, xlab = NULL, ylab = NULL, ...)
 {
     HN <- function (pars, r) {
         g0 <- pars[1]; sigma <- pars[2]
@@ -35,51 +36,56 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
         g0 <- pars[1]; sigma <- pars[2]; w <- pars[3]
         ifelse(r<=w, g0, g0*exp (-(r-w) / sigma))
     }
+    ANN <- function (pars, r) {
+        g0 <- pars[1]; sigma <- pars[2]; w <- pars[3]
+        g0 * exp (-(r-w)^2 / 2 / sigma^2)
+    }
     SS <- function (pars, r) {
         beta0 <- pars[1]; beta1 <- pars[2]; sdS <- pars[3]
-        if (is.null(x$details$cutval)) 
+        if (is.null(x$details$cutval))
             stop ('require cut parameter for signal strength plot')
         mu <- beta0 + beta1 * r
         1 - pnorm (q=x$details$cutval, mean=mu, sd=sdS)
     }
     SSS <- function (pars, r) {
         beta0 <- pars[1]; beta1 <- pars[2]; sdS <- pars[3]
-        if (is.null(x$details$cutval)) 
+        if (is.null(x$details$cutval))
             stop ('require cut parameter for signal strength plot')
         ## spherical so assume distance r measured from 1 m
         mu <- beta0 - 10 * log ( r^2 ) / 2.302585 + beta1 * (r-1)
         mu[r<1] <- beta0
         1 - pnorm (q=x$details$cutval, mean=mu, sd=sdS)
     }
-  
+
     gline <- function (predicted, rowi = 1, eps = 1e-10) {
         ## eps is used to limit y to range where gradient() works
         ## may need later adjustment
         if (!is.data.frame(predicted)) {
             out <- list()
-            for (i in 1:length(predicted)) 
+            for (i in 1:length(predicted))
                 out[[i]] <- gline(predicted[[i]], i)
             names(out) <- names(predicted)
             out
-        } 
+        }
         else {
-        
-            parnames <- switch (x$detectfn+1, 
+
+            parnames <- switch (x$detectfn+1,
                 c('g0','sigma'),
                 c('g0','sigma','z'),
                 c('g0','sigma'),
-                c('g0','sigma'),
                 c('g0','sigma','z'),
+                c('g0','sigma'),
                 c('g0','sigma','w'),
-                ,,,,
+                c('g0','sigma','w'),
+                ,,,
                 c('beta0','beta1', 'sdS'),
                 c('beta0','beta1', 'sdS')
             )
-    
-            pars <- predicted[parnames,'estimate']  
-      
+
+            pars <- predicted[parnames,'estimate']
+
             pars[is.na(pars)] <- unlist(x$fixed)
-            dfn <- switch (x$detectfn+1, HN, HZ, EX, UN, CHN, WEX,,,,,SS,SSS)   ## omits binary SS!
+            dfn <- switch (x$detectfn+1, HN, HZ, EX, UN, CHN, WEX, ANN,,,,SS,SSS)   ## omits binary SS!
             if (sigmatick) {
               sigma <- pars[2]
               y <- dfn(pars, sigma)
@@ -88,21 +94,21 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
             }
 
             y <- dfn(pars, xval)
-  
+
             if (rgr) {
               y <- xval * y
               ymax <- par()$usr[4]
-              lines (xval, y * 0.8 * ymax / max(y), lty = 2, ...)  
+              lines (xval, y * 0.8 * ymax / max(y), lty = 2, ...)
             }
             else lines (xval, y, ...)
-    
+
             if (limits & !rgr) {
                 ## delta method variance of g()
-    
+
                 grad <- matrix(nr=length(xval), nc=length(x$fit$par))  ## beta pars
                 if (is.null(newdata)) newdata <- secr.make.newdata (x)
                 lkdfn <- function (beta, r) {
-                    ## real g() from all beta pars and model.matrix 
+                    ## real g() from all beta pars and model.matrix
                     real <- numeric(length(parnames))
                     names(real) <- parnames
                     for (rn in parnames) {
@@ -113,9 +119,9 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
                     }
                     ## dfn(real, r)   # on natural scale
                     logit(dfn(real, r))
-                } 
+                }
 
-                for (i in 1:length(xval)) 
+                for (i in 1:length(xval))
 
             ## Fast special cases: checking only
             ##    if ((x$detectfn==0) & (all(sapply(x$model, function(m) m == ~1)) ))
@@ -127,11 +133,11 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
             ##        ## D(expression(1/(1+exp(-g0)) * exp(-r^2/2/exp(sigma)^2)), 'g0')
             ##        ## D(expression(1/(1+exp(-g0)) * exp(-r^2/2/exp(sigma)^2)), 'sigma')
             ##        tempgrad <- c(exp(-g0)/(1 + exp(-g0))^2 * exp(-r^2/2/exp(sigma)^2),
-            ##            -(1/(1 + exp(-g0)) * (exp(-r^2/2/exp(sigma)^2) * (-r^2/2 * (2 * (exp(sigma) 
+            ##            -(1/(1 + exp(-g0)) * (exp(-r^2/2/exp(sigma)^2) * (-r^2/2 * (2 * (exp(sigma)
             ##            * exp(sigma)))/(exp(sigma)^2)^2))))
             ##        if (!x$CL) tempgrad <- c(0,tempgrad)  ## for density
             ##        grad[i,] <- tempgrad
-            ##    } 
+            ##    }
             ##    else
             ##       if ((x$detectfn==1) & (all(sapply(x$model, function(m) m == ~1)) ))
             ##    {
@@ -142,14 +148,14 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
             ##           r <- xval[i]
             ##        tempgrad <- c(
             ##            exp(-g0)/(1 + exp(-g0))^2 * (1 - exp(-(r/exp(sigma))^(-exp(z)))),
-            ##            -(1/(1 + exp(-g0)) * (exp(-(r/exp(sigma))^(-exp(z))) * ((r/exp(sigma))^((-exp(z)) - 
+            ##            -(1/(1 + exp(-g0)) * (exp(-(r/exp(sigma))^(-exp(z))) * ((r/exp(sigma))^((-exp(z)) -
             ##            1) * ((-exp(z)) * (r * exp(sigma)/exp(sigma)^2))))),
-            ##            -(1/(1 + exp(-g0)) * (exp(-(r/exp(sigma))^(-exp(z))) * ((r/exp(sigma))^(-exp(z)) * 
+            ##            -(1/(1 + exp(-g0)) * (exp(-(r/exp(sigma))^(-exp(z))) * ((r/exp(sigma))^(-exp(z)) *
             ##            (log((r/exp(sigma))) * exp(z)))))
             ##        )
             ##        if (!x$CL) tempgrad <- c(0,tempgrad)  ## for density
             ##        grad[i,] <- tempgrad
-            ##    } 
+            ##    }
             ##    else
 
                 # grad[i,] <- fdHess (pars = x$fit$par, fun = lkdfn, r = xval[i])$gradient
@@ -163,16 +169,16 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
                 ## ucl <- pmin(y + z*se,1)
 
                 ## limits on link scale
-                lcl <- ifelse ((y>eps) & (y<(1-eps)), invlogit (logit(y) - z*se), NA) 
+                lcl <- ifelse ((y>eps) & (y<(1-eps)), invlogit (logit(y) - z*se), NA)
                 ucl <- ifelse ((y>eps) & (y<(1-eps)), invlogit (logit(y) + z*se), NA)
 
-                lines (xval, lcl, lty=2, ...)            
-                lines (xval, ucl, lty=2, ...)            
+                lines (xval, lcl, lty=2, ...)
+                lines (xval, ucl, lty=2, ...)
             }
-    
+
             if (limits & !rgr)
                 data.frame(x=xval, y=y, lcl = lcl, ucl = ucl)
-            else 
+            else
                 data.frame(x=xval, y=y)
         }
     }
@@ -183,7 +189,7 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
         if (x$detectfn %in% c(10,11)) {
             ylim <- c(0, 1)
         }
-        else { 
+        else {
             getmax <- function(x) {
                 g0 <- x['g0','estimate']
                 se.g0 <- x['g0','SE.estimate']
@@ -193,23 +199,23 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
             else maxg0 <- max(sapply (temp, getmax))
 
             if (is.na(maxg0)) maxg0 <- x$fixed$g0
-            if (maxg0 > 0.75) maxg0 <- max(maxg0,1)          
+            if (maxg0 > 0.75) maxg0 <- max(maxg0,1)
             ylim <- c(0, maxg0)
         }
     }
     if (!add) {
-        if (is.null(xlab)) 
+        if (is.null(xlab))
             xlab <- 'Distance  (m)'
         if (is.null(ylab)) {
            binomN <- ifelse(is.null(x$details$binomN),0,x$details$binomN)
            dlambda <- (detector(traps(x$capthist)) %in% c('quadratbinary', 'polygon')) |
                ((detector(traps(x$capthist)) %in% c('count','quadratcount')) & (binomN==0))
-           if (dlambda) 
+           if (dlambda)
                ylab <- 'Detection lambda'
            else
                ylab <- 'Detection probability'
-        }      
-        plot (type ='n', 0,0, xlim=range(xval), ylim=ylim, 
+        }
+        plot (type ='n', 0,0, xlim=range(xval), ylim=ylim,
             xlab=xlab, ylab=ylab,...)
     }
     invisible(gline(temp))
@@ -217,8 +223,8 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
 ############################################################################################
 
 detectfnplot <- function (detectfn, pars, details = NULL,
-    add = FALSE, sigmatick = FALSE, rgr = FALSE,  
-    xval = 0:200, ylim = NULL, xlab = NULL, ylab = NULL, ...) 
+    add = FALSE, sigmatick = FALSE, rgr = FALSE,
+    xval = 0:200, ylim = NULL, xlab = NULL, ylab = NULL, ...)
 {
     HN <- function (pars, r) {
         g0 <- pars[1]; sigma <- pars[2]
@@ -246,28 +252,32 @@ detectfnplot <- function (detectfn, pars, details = NULL,
         g0 <- pars[1]; sigma <- pars[2]; w <- pars[3]
         ifelse(r<=w, g0, g0*exp (-(r-w) / sigma))
     }
+    ANN <- function (pars, r) {
+        g0 <- pars[1]; sigma <- pars[2]; w <- pars[3]
+        g0 * exp (-(r-w)^2 / 2 / sigma^2)
+    }
     SS <- function (pars, r) {
         beta0 <- pars[1]; beta1 <- pars[2]; sdS <- pars[3]
-        if (is.null(details$cutval)) 
+        if (is.null(details$cutval))
             stop ('require cut parameter for signal strength plot')
         mu <- beta0 + beta1 * r
         1 - pnorm (q=details$cutval, mean=mu, sd=sdS)
     }
-  
+
     SSS <- function (pars, r) {
         beta0 <- pars[1]; beta1 <- pars[2]; sdS <- pars[3]
-        if (is.null(details$cutval)) 
+        if (is.null(details$cutval))
             stop ('require cut parameter for signal strength plot')
         ## spherical so assume distance r measured from 1 m
         mu <- beta0 - 10 * log ( r^2 ) / 2.302585 + beta1 * (r-1)
         mu[r<1] <- beta0
         1 - pnorm (q=details$cutval, mean=mu, sd=sdS)
     }
-  
+
     gline <- function (pars) {
         ## here pars is a vector of parameter values
 
-        dfn <- switch (detectfn+1, HN, HZ, EX, UN, CHN, WEX,,,,,SS,SSS)
+        dfn <- switch (detectfn+1, HN, HZ, EX, UN, CHN, WEX, ANN,,,,SS,SSS)
         if (sigmatick) {
             sigma <- pars[2]
             y <- dfn(sigma, pars)
@@ -278,7 +288,7 @@ detectfnplot <- function (detectfn, pars, details = NULL,
         if (rgr) {
             y <- xval * y
             ymax <- par()$usr[4]
-            lines (xval, y * 0.8 * ymax / max(y), lty = 2, ...)  
+            lines (xval, y * 0.8 * ymax / max(y), lty = 2, ...)
         }
         else lines (xval, y, ...)
 
@@ -290,9 +300,13 @@ detectfnplot <- function (detectfn, pars, details = NULL,
 
     if (!is.matrix(pars)) pars <- matrix(pars, nr=1)
 
-    needp <- c(2,3,2,2,3,3,0,0,0,0,3,3)[detectfn+1]
+    ## added 2010-07-01
+    if (is.character(detectfn))
+        detectfn <- detectionfunctionnumber(detectfn)
+
+    needp <- c(2,3,2,3,2,3,3,0,0,0,3,3)[detectfn+1]
     nam <- c('halfnormal','hazard','exponential','uniform','compound halfnormal',
-        'w exponential',"","","","", 'signal strength', 'binary signal strength')
+        'w exponential', 'annular normal',"","","", 'signal strength', 'binary signal strength')
     if (ncol(pars) != needp)
         stop(paste('require', needp, 'parameters for', nam[detectfn+1], 'detection function'))
 
@@ -300,17 +314,17 @@ detectfnplot <- function (detectfn, pars, details = NULL,
         if (detectfn %in% c(10,11)) {
             ylim <- c(0, 1)
         }
-        else { 
+        else {
             ylim <- c(0, max(pars[,1]))   ## g0
         }
     }
 
     if (!add) {
-        if (is.null(xlab)) 
+        if (is.null(xlab))
             xlab <- 'Distance  (m)'
         if (is.null(ylab))
             ylab <- 'Detection'
-        plot (type ='n', 0,0, xlim=range(xval), ylim=ylim, 
+        plot (type ='n', 0,0, xlim=range(xval), ylim=ylim,
             xlab=xlab, ylab=ylab,...)
     }
 
@@ -349,11 +363,11 @@ attenuationplot <- function (pars, add = FALSE, spherical = TRUE,
     }
 
     if (!add) {
-        if (is.null(xlab)) 
+        if (is.null(xlab))
             xlab <- 'Distance  (m)'
         if (is.null(ylab))
             ylab <- 'Acoustic power (dB)'
-        plot (type ='n', 0,0, xlim=range(xval), ylim=ylim, 
+        plot (type ='n', 0,0, xlim=range(xval), ylim=ylim,
             xlab=xlab, ylab=ylab,...)
     }
     invisible( apply (pars, 1, aline) )
