@@ -90,7 +90,7 @@ prepare <- function (secr, newmodel) {
 
 mapbeta <- function (parindx0, parindx1, beta0, betaindex) 
 
-## Extend beta vector from simple model (beta0) to a more complex 
+## Extend beta vector from simple model (beta0) to a more complex (i.e. general)
 ## model, inserting neutral values (zero) as required.
 ## For each real parameter, a 1:1 match is assumed between 
 ## beta values until all beta values from the simpler model are
@@ -98,21 +98,22 @@ mapbeta <- function (parindx0, parindx1, beta0, betaindex)
 ## betaindex is a user-controlled alternative.
 
 {
-  ## list of zeroed vectors, one per real parameter
-  beta1 <- lapply(parindx1, function (x) {x[]<-0; x})
-
-  if (!is.null(betaindex)) {
-      beta1 <- unlist(beta1)
-      if (sum(betaindex>0) != length(beta0)) stop ('invalid betaindex', call.=F)
-      beta1[betaindex] <- beta0
-      beta1
-  }
-  else {
-      indx <- lapply(parindx0, function(x) x-x[1]+1)
-      for (j in 1:length(beta1))
-        beta1[[j]][indx[[j]]] <- beta0[parindx0[[j]]]
-      unlist(beta1)
-  }
+    ## list of zeroed vectors, one per real parameter
+    beta1 <- lapply(parindx1, function (x) {x[]<-0; x})
+  
+    if (!is.null(betaindex)) {
+        beta1 <- unlist(beta1)
+        if (sum(betaindex>0) != length(beta0)) 
+            stop ('invalid betaindex', call.=F)
+        beta1[betaindex] <- beta0
+        beta1
+    }
+    else {
+        indx <- lapply(parindx0, function(x) x-x[1]+1)
+        for (j in 1:length(beta1))
+          beta1[[j]][indx[[j]]] <- beta0[parindx0[[j]]]
+        unlist(beta1)
+    }
 }
 ############################################################################################
 
