@@ -10,7 +10,7 @@
 ## source ('d:\\density secr 1.2\\secr\\R\\secr.design.MS.R')
 ############################################################################################
 
-secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL, 
+secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     groups = NULL, dframe = NULL, naive = FALSE, bygroup = FALSE, ...) {
 
 ## Generate design matrix, reduced parameter array, and parameter index array (PIA)
@@ -18,7 +18,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 ## 'capthist' must be of class 'capthist' or 'list'
 ##
 ## uses pad1 to pad session-specific covar to constant length with first value,
-## defined in 'functions.R' 
+## defined in 'functions.R'
 
     findvars.MS <- function (cov, vars, dimcov) {
         ## function to add covariates to a design data frame 'dframe'
@@ -27,7 +27,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
         ## uses pad1 and insertdim from functions.R
         ## NOT to be used to add group variables
         ## Does not yet standardize numeric covariates if (!is.factor(vals)) vals <- stdfn(vals)
-    
+
         if (is.null(cov) | (length(cov)==0) | (length(vars)==0)) return()
         else {
             found <- ''
@@ -37,16 +37,16 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
                 varincov <- sapply(covnames, function(nam) vars %in% nam)
                 if (length(vars)>1) found <- vars[apply(varincov,1,all)]
                 else found <- vars[all(varincov)]
-    
-                for (variable in found) {    
-                    vals <- unlist(lapply(cov, function(x) pad1(x[,variable], 
+
+                for (variable in found) {
+                    vals <- unlist(lapply(cov, function(x) pad1(x[,variable],
                         dims[dimcov])))
                     if (any(is.na(vals))) stop ('covariate missing values not allowed')
 
                     dframe[,variable] <<- insertdim (vals, dimcov, dims)
                 }
             }
-            else  
+            else
             {
                 found <- names(cov) %in% vars
                 if (is.data.frame(cov) & any(found)) {
@@ -54,7 +54,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
                     values <- as.data.frame(cov[,found])
                     names(values) <- found
                     if (length(values)>0) {
-                        for (variable in found) {    
+                        for (variable in found) {
                             vals <- values[,variable]
                             dframe[,variable] <<- insertdim (vals, dimcov, dims)
                         }
@@ -69,7 +69,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     # This setting is used for 'naive' table
     # groups is a vector of factor names whose intersection defines group
     # groups only defined for CL = T
-    # use of 'g' requires valid groups definition 
+    # use of 'g' requires valid groups definition
     # grouping variables are also added individually to dframe
 
     models$D <- NULL                          # drop density model
@@ -79,14 +79,14 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     vars     <- vars[!(vars %in% groups)]     # groups treated separately
     nmix     <- get.nmix(models)
 
-##    if (sum(c('b','B','bk','Bk') %in% vars) > 1) 
-    if (sum(c('b','B') %in% vars) > 1) 
+##    if (sum(c('b','B','bk','Bk') %in% vars) > 1)
+    if (sum(c('b','B') %in% vars) > 1)
     stop ('model should not use more than one type of behavioural response')
     trps    <- traps(capthist)                 # session-specific trap array
     used    <- usage(trps)                     # session-specific usage
     zcov    <- covariates(capthist)            # session-specific individual covariates
     trapcov <- covariates(trps)                # session-specific trap covariates
-    if (('g' %in% vars) & is.null(groups)) stop ('Require valid group covariate') 
+    if (('g' %in% vars) & is.null(groups)) stop ('Require valid group covariate')
     grps    <- group.levels(capthist,groups)
     ngrp    <- max(1,length(grps))
 
@@ -95,14 +95,14 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     sessionlevels <- session(capthist)
     if (is.null(sessionlevels)) sessionlevels <- '1'
     getnk <- function (object) {
-        ifelse (detector(object) %in% c('polygon','transect'), 
-            length(table(polyID(object))), 
+        ifelse (detector(object) %in% c('polygon','transect'),
+            length(table(polyID(object))),
             nrow(object))
     }
 
     if (MS) {
         R <- length(capthist)
-        n <- ifelse (bygroup, ngrp, max(sapply(capthist, nrow))) # max over sessions 
+        n <- ifelse (bygroup, ngrp, max(sapply(capthist, nrow))) # max over sessions
         S <- max(sapply(capthist, ncol))                         # max over sessions
         K <- max(sapply(trps, getnk))                            # max over sessions
     }
@@ -129,7 +129,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     }
 
     dims <- c(R,n,S,K,nmix)  # 'virtual' dimensions
-    autovars <- c('session','g','t','T','b','B','kcov','tcov', 'sighting', 'h2', 'h3')
+    autovars <- c('session','Session','g','t','T','b','B','kcov','tcov', 'sighting', 'h2', 'h3')
     if (is.null(dframe)) dframe <- data.frame(dummy=rep(1, R*n*S*K*nmix))
 
 ## BUG FIXED 2009 12 22
@@ -138,13 +138,14 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 ##    dframe$session <- factor( insertdim (sessionlevels, 1, dims))
 
     dframe$session <- factor( insertdim (sessionlevels, 1, dims), levels = sessionlevels)
+    dframe$Session <- insertdim (0:(R-1), 1, dims)
 
     #--------------------------------------------------------------------------
-    if ('t' %in% vars) 
+    if ('t' %in% vars)
         dframe$t <- factor( insertdim (1:S, 3, dims) )
 
     #--------------------------------------------------------------------------
-    ## 2009 10 07 mark-resight 
+    ## 2009 10 07 mark-resight
     q <- attr(capthist, 'q')
     if (any((q > 0) & (q < S))) {
         ## marking  on occasions 1:q, sighting on occasions (q+1):S
@@ -158,7 +159,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
         ################
         # add g factor
 
-        if (bygroup) 
+        if (bygroup)
             gvar <- factor(grps)
         else {
             gvar <- group.factor(capthist, groups)          # list if MS
@@ -168,24 +169,24 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
         dframe$g <- insertdim ( unlist(gvar), c(2,1), dims)  ## unlist works on factors, too
 
         #################################
-        # also add separate group factors  
+        # also add separate group factors
 
         # if bygroup, just use group levels for each session
-        # else get group membership from covariates(capthist) for each session, 
-        # and pad to max(n) if needed 
+        # else get group membership from covariates(capthist) for each session,
+        # and pad to max(n) if needed
 
         if (bygroup) {
             MSlevels <- function (facname) {
                 ## assume all sessions the same without checking
-                if (inherits(capthist, 'list')) levels(zcov[[1]][,facname]) 
+                if (inherits(capthist, 'list')) levels(zcov[[1]][,facname])
                 else levels(zcov[,facname])
-            } 
+            }
 
             ## list with levels for each grouping factor named in 'groups'
             grouplist <- lapply(groups, MSlevels)
             grouping <- expand.grid(grouplist) ## one column per group
             names(grouping) <- groups
-            for (i in groups) insertdim(grouping[,i], c(2,1), dims)  ## all sessions the same         
+            for (i in groups) insertdim(grouping[,i], c(2,1), dims)  ## all sessions the same
         }
         else {
             for (i in groups) {
@@ -194,15 +195,15 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
                     grouping <- unlist(lapply(grouping, pad1, n))
                 }
                 else grouping <- zcov[,i]
-                insertdim(grouping, c(2,1), dims)  
+                insertdim(grouping, c(2,1), dims)
             }
-        }       
+        }
     }
     #--------------------------------------------------------------------------
 
     ## general for behavioural response fields
 
-    prox <- detector(trps)[[1]] %in% c('proximity', 'count', 'quadratbinary', 'quadratcount', 'polygon') ## assume all sessions same type 
+    prox <- detector(trps)[[1]] %in% c('proximity', 'count', 'quadratbinary', 'quadratcount', 'polygon') ## assume all sessions same type
     makeb <- function (caphist) {      ## global response
         if (prox) {
            temp0 <- apply(caphist, 1:2, sum)
@@ -218,7 +219,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 ##        else {
 ##            temp0 <- array (dim=c(n,S,K))
 ##            temp0[,,] <- 0
-##            indices <- cbind(as.numeric(row(caphist)), 
+##            indices <- cbind(as.numeric(row(caphist)),
 ##                as.numeric(col(caphist)), as.numeric(abs(caphist)))
 ##            temp0[indices] <- 1
 ##            temp <- apply(temp0, c(1,3), prevcapt)
@@ -231,7 +232,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     if ('b' %in% vars) {
         if (naive) dframe$b <- rep(0, R*n*S*K)
         else {
-            prevcapt <- function(x) c(F, cumsum(x[-S])>0)      
+            prevcapt <- function(x) c(F, cumsum(x[-S])>0)
             if (MS) {
                 temp <- lapply(capthist, makeb)
                 temp <- lapply(temp, padarray, c(n,S))
@@ -247,7 +248,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     if ('B' %in% vars) {
         if (naive) dframe$B <- rep(0, R*n*S*K)
         else {
-            prevcapt <- function(x) c(F, x[-S]>0) 
+            prevcapt <- function(x) c(F, x[-S]>0)
             if (MS) {
                 temp <- lapply(capthist, makeb)
                 temp <- lapply(temp, padarray, c(n,S))
@@ -262,7 +263,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 ##    if ('bk' %in% vars) {
 ##        if (naive) dframe$bk <- rep(0, R*n*S*K)
 ##        else {
-##            prevcapt <- function(x) c(F, cumsum(x[-S])>0)      
+##            prevcapt <- function(x) c(F, cumsum(x[-S])>0)
 ##            if (MS) {
 ##                temp <- lapply(capthist, makebk)
 ##                temp <- lapply(temp, padarray, c(n,S,K))
@@ -276,7 +277,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 ##    if ('Bk' %in% vars) {
 ##        if (naive) dframe$Bk <- rep(0, R*n*S*K)
 ##        else {
-##            prevcapt <- function(x) c(F, x[-S]>0) 
+##            prevcapt <- function(x) c(F, x[-S]>0)
 ##            if (MS) {
 ##                temp <- lapply(capthist, makebk)
 ##                temp <- lapply(temp, padarray, c(n,S,K))
@@ -290,7 +291,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     #--------------------------------------------------------------------------
 
     if ('tcov' %in% vars) {
-        if (is.null(timecov)) 
+        if (is.null(timecov))
             stop ('Require valid time covariate timecov')
         if (length(unlist(timecov)) > S)                                             ### CHECK
             warning ('length of time covariate exceeds number of occasions')
@@ -302,13 +303,13 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
         else {
             if (any(sapply(timecov, nrow) < S))
                 stop ('Require valid time covariate timecov')
-            timecov <- lapply (timecov, function(x) pad1(x[,1], S))         
+            timecov <- lapply (timecov, function(x) pad1(x[,1], S))
         }
-        dframe$tcov <- insertdim (unlist(timecov), c(3,1), dims) 
+        dframe$tcov <- insertdim (unlist(timecov), c(3,1), dims)
     }
 
     if ('T' %in% vars) {
-        dframe$T <- insertdim (0:(S-1), c(3,1), dims) 
+        dframe$T <- insertdim (0:(S-1), c(3,1), dims)
     }
 
     #--------------------------------------------------------------------------
@@ -316,21 +317,21 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
         if (is.null(trapcov))
             stop ('Model uses trap covariates, but valid covariate data not found')
         if (is.data.frame(trapcov)) trapcov <- trapcov[,1,drop=F]  ## retain only first
-        else trapcov <- lapply (trapcov, function(x) pad1(x[,1], K)) 
+        else trapcov <- lapply (trapcov, function(x) pad1(x[,1], K))
         dframe$kcov <- insertdim(unlist(trapcov), c(4,1), dims)
     }
 
     #--------------------------------------------------------------------------
 
 
-    ## h2 or h3 
+    ## h2 or h3
     if (nmix > 1) {
         mixture <- paste('h',nmix,sep='')
         dframe[,mixture] <- insertdim(factor(1:nmix), 5, dims)
     }
 
-    #--------------------------------------------------------------------------   
-    ## all autovars should have now been dealt with 
+    #--------------------------------------------------------------------------
+    ## all autovars should have now been dealt with
     vars <- vars[!vars %in% autovars]
 
     #--------------------------------------------------------------------------
@@ -338,9 +339,9 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 
     if ((length(vars)>1) & (R>1)) warning ('Implementation of user covariates with multi-session data is untested')
 
-    if (!bygroup) findvars.MS (zcov, vars, 2)   ## CL only   
+    if (!bygroup) findvars.MS (zcov, vars, 2)   ## CL only
     ## possible alternative for consideration 2009 09 25
-    ## findvars.MS (zcov, vars, 2) 
+    ## findvars.MS (zcov, vars, 2)
 
     findvars.MS (sessioncov, vars, 1)
     findvars.MS (timecov, vars, 3)      ## session-specific list
@@ -358,10 +359,10 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
         else {
             tempmat <- model.matrix(formula, dframe, ...)
             ## drop pmix beta0 column from design matrix
-            if (prefix=='pmix') tempmat <- tempmat[,-1,drop=FALSE]      
+            if (prefix=='pmix') tempmat <- tempmat[,-1,drop=FALSE]
             temp <- make.lookup (tempmat)   # retain unique rows
             list (model=temp$lookup, index=temp$index)
-        } 
+        }
     }
 
     ## replace NA with dummy value '0' to stop model.matrix dropping rows added as padding
@@ -372,7 +373,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     # each of these is a list with components 'model' and 'index'
 
 ##    designMatrices <- lapply (models, make.designmatrix)
-    designMatrices <- sapply (1:length(models), simplify=FALSE, 
+    designMatrices <- sapply (1:length(models), simplify=FALSE,
         function (x) make.designmatrix(models[[x]], names(models[x])))
     names(designMatrices) <- names(models)
 
@@ -382,11 +383,11 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
     indices <- matrix(unlist(indices), nc=npar)
 
     # retain just the 'model' components of 'designMatrices'
-    designMatrices <- lapply (designMatrices, function(x)x$model ) 
+    designMatrices <- lapply (designMatrices, function(x)x$model )
 
-    # prefix column names in 'designMatrices' with parameter name   
-    for (i in 1:npar) 
-        colnames(designMatrices[[i]]) <- paste (parnames[i], '.', 
+    # prefix column names in 'designMatrices' with parameter name
+    for (i in 1:npar)
+        colnames(designMatrices[[i]]) <- paste (parnames[i], '.',
             colnames(designMatrices[[i]]), sep='')
 
     # repackage indices to define unique combinations of parameters
@@ -412,7 +413,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
 
     # 'used' is list if MS
 
-## OOPS - TOO TIRED TO THINK THROUGH THE IMPLEMENTATION OF USE WITH MIXTURES 
+## OOPS - TOO TIRED TO THINK THROUGH THE IMPLEMENTATION OF USE WITH MIXTURES
 ## UNSURE FROM HERE 2009 12 10
 
     if ((!is.null(used)) & (length(used)>0)) {
@@ -429,7 +430,7 @@ secr.design.MS <- function (capthist, models, timecov = NULL, sessioncov = NULL,
                 use[1:nrow(temp), 1:ncol(temp)] <- temp  # padding
 ##                PIA[r, , , ] <- PIA[r, , , ] * rep(use,rep(n,S*K))
                 PIA[r, , , ,] <- PIA[r, , , ,] * rep(rep(use,rep(n,S*K)),nmix)
-            } 
+            }
         }
     }
 
