@@ -1,10 +1,13 @@
 ############################################################################################
 ## package 'secr'
 ## secr.make.newdata.R
-## last changed 
+## last changed
 ## 2009 12 13 (mixtures)
 ## 2010 03 10 'T'
-## Create (neutral) design data suitable for 'predict' 
+## 2010 06 17 'Session'
+## 2010 06 21 'x2', 'y2', 'xy'
+## 2010 08 28 fix bug with T
+## Create (neutral) design data suitable for 'predict'
 ############################################################################################
 
 secr.make.newdata <- function (object) {
@@ -25,7 +28,7 @@ secr.make.newdata <- function (object) {
         ## uses pad1 and insertdim from functions.R
         ## NOT to be used to add group variables
         ## Does not yet standardize numeric covariates if (!is.factor(vals)) vals <- stdfn(vals)
-    
+
         if (is.null(cov) | (length(cov)==0) | (length(vars)==0)) return()
         else {
             found <- ''
@@ -35,14 +38,14 @@ secr.make.newdata <- function (object) {
                 varincov <- sapply(covnames, function(nam) vars %in% nam)
                 if (length(vars)>1) found <- vars[apply(varincov,1,all)]
                 else found <- vars[all(varincov)]
-    
-                for (variable in found) {    
+
+                for (variable in found) {
                     vals <- unlist(lapply(cov, function(x) rep(x[1,variable],   ## use first occurrence!
                         dims[dimcov])))
                     newdata[,variable] <<- insertdim (vals, dimcov, dims)
                 }
             }
-            else  
+            else
             {
                 found <- names(cov) %in% vars
                 if (is.data.frame(cov) & any(found)) {
@@ -50,7 +53,7 @@ secr.make.newdata <- function (object) {
                     values <- as.data.frame(cov[,found])
                     names(values) <- found
                     if (length(values)>0) {
-                        for (variable in found) {    
+                        for (variable in found) {
                             if (use.all) vals <- values[,variable]
                             else  vals <- values[1,variable]
                             newdata[,variable] <<- insertdim (vals, dimcov, dims)
@@ -74,30 +77,36 @@ secr.make.newdata <- function (object) {
     newdata <- expand.grid(basevars)
     nr <- nrow(newdata)  ## one row for each session, group and mixture
     if (ngrp==1)
-        findvars.MS (covariates(capthist), vars, 1, FALSE) ## check for indiv cov  
-    
+        findvars.MS (covariates(capthist), vars, 1, FALSE) ## check for indiv cov
     for (v in vars) {
         if (v=='x') newdata$x <- rep(0,nr)   # mean attr(mask,'meanSD')[1,'x']
         if (v=='y') newdata$y <- rep(0,nr)   # mean attr(mask,'meanSD')[1,'y']
+        if (v=='x2') newdata$x2 <- rep(0,nr)   # mean attr(mask,'meanSD')[1,'x']
+        if (v=='y2') newdata$y2 <- rep(0,nr)   # mean attr(mask,'meanSD')[1,'y']
+        if (v=='xy') newdata$xy <- rep(0,nr)   # mean attr(mask,'meanSD')[1,'x']
         if (v=='t') newdata$t <- rep(factor(1, levels=1:nocc), nr)   ## mod 2009 09 03
-        if (v=='T') newdata$T <- rep(0:(nocc-1), nr)   ## 2010 03 10
+##        if (v=='T') newdata$T <- rep(0:(nocc-1), nr)   ## 2010 03 10
+        if (v=='T') newdata$T <- rep(0, nr)   ## 2010 08 28
         if (v=='b') newdata$b <- rep(factor(0, levels=c(0,1)),nr)    # naive
         if (v=='B') newdata$B <- rep(factor(0, levels=c(0,1)),nr)    # naive
 #        if (v=='bk') newdata$bk <- rep(factor(0, levels=c(0,1)),nr)   # naive
 #        if (v=='Bk') newdata$Bk <- rep(factor(0, levels=c(0,1)),nr)   # naive
         if (v=='tcov') newdata$tcov <- rep(0,nr)        # ideally use mean or standardize?
         if (v=='kcov') newdata$kcov <- rep(0,nr)        # ditto
+        if (v=='Session') newdata$Session <- as.numeric( factor(newdata$session,
+            levels = session(capthist) ) ) - 1    # based on sequence in capthist
     }
 
-    ## all autovars should now have been dealt with 
-    vars <- vars[!vars %in% c('g','x','y','session','t','T','b','B','tcov','kcov','h2','h3')]
+    ## all autovars should now have been dealt with
+    vars <- vars[!vars %in% c('g','x','y','x2','y2','xy','session','Session','t','T','b','B','tcov','kcov','h2','h3')]
 
-    findvars.MS (sessioncov, vars, 1, TRUE)   
-    findvars.MS (timecov, vars, 1, FALSE)   
-    findvars.MS (covariates(traps(capthist)), vars, 1, FALSE)   
+    findvars.MS (sessioncov, vars, 1, TRUE)
+    findvars.MS (timecov, vars, 1, FALSE)
+    findvars.MS (covariates(traps(capthist)), vars, 1, FALSE)
 
     ## default all remaining vars to numeric zero
     for (v in vars) newdata[,v] <- rep(0,nr)
+
     newdata
 }
 ############################################################################################
